Settings — django-vintage v0.1 documentation

django-vintage v0.1 documentation

# Settings

- Table of Contents
- index
  next
  previous

# Settings

- Default settings
- METADATA_FORM
- STORAGE

## Default settings

    VINTAGE_SETTINGS = {
        'METADATA_FORM': 'vintage.metadata_form.MetadataForm',
        'STORAGE': settings.DEFAULT_FILE_STORAGE,
    }

## METADATA_FORM

This string is a Python path to the Django `Form` that displays, manages and validates the metadata.

## STORAGE

The Django storage class to use for saving the `ArchivedFile`s.